@@ -1,7 +1,6 @@
 import re
 import click
-import os
-from dulwich.repo import Repo
+import subprocess
 import urllib.request, json
 from ...utils.token import parse_token
 
@@ -15,11 +14,11 @@ def build(build_number, source):
       raise click.BadParameter('--source should be REPO_NAME=REPO_DIST')
 
   repos = [s.split('=') for s in source]
-  sources = [(name, Repo(repo_dist).head().decode('ascii')) for name, repo_dist in repos]
+  sources = [(name, subprocess.check_output("git rev-parse HEAD".split(), cwd=repo_dist).decode()) for name, repo_dist in repos]
   submodules = []
   for repo_name, repo_dist in repos:
     # invoke git directly because dulwich's submodule feature was broken
-    submodule_stdouts = os.popen("cd {};git submodule status --recursive".format(repo_dist)).read().splitlines()
+    submodule_stdouts = subprocess.check_output("git submodule status --recursive".split(), cwd=repo_dist).decode().splitlines()
     for submodule_stdout in submodule_stdouts:
       # the output is e.g. "+bbf213437a65e82dd6dda4391ecc5d598200a6ce sub1 (heads/master)"
       matched = re.search(r"^[\+\-U ](?P<hash>[a-f0-9]{40}) (?P<name>\w+)", submodule_stdout)
@@ -27,7 +26,7 @@ def build(build_number, source):
         hash = matched.group('hash')
         name = matched.group('name')        
         if hash and name:
-          submodules.append((name, hash))
+          submodules.append((repo_name+"/"+name, hash))
 
   # Note: currently becomes unique command args and submodules by the hash. But they can be conflict between repositories.
   uniq_submodules = {hash: (name, hash) for name, hash in sources + submodules}.values()
@@ -60,4 +59,4 @@ def build(build_number, source):
       print(response_body)
 
   except Exception as e:
-    print(e)
\ No newline at end of file
+    print(e)
